pub enum Executions {
AllocatedNoExecutions,
Executed(NonEmpty<Execution>),
}Expand description
The result of executing an order against the order book.
Example
use clob_sync::prelude::{Executions, Execution, OrderId, Quantity};
use nonempty::NonEmpty;
let no_exec = Executions::AllocatedNoExecutions;
let executed = Executions::Executed(NonEmpty::new(
Execution::FullExecution(OrderId::default())
));Variants
AllocatedNoExecutions
Order was added to the book without any executions
Executed(NonEmpty<Execution>)
Order was fully or partially executed