pub struct Matches {
pub matches: Vec<Match>,
pub remaining_incoming_order: Option<Quantity>,
}Expand description
The result of attempting to cross an order against the book.
Fields
matches: Vec<Match>All matches that occurred during the cross
remaining_incoming_order: Option<Quantity>If not None, the remaining quantity of the incoming order (i.e., quantity that couldn’t be matched)