OrderBookSide

Trait OrderBookSide 

pub trait OrderBookSide: Sealed {
    // Required methods
    fn try_cross(&mut self, order: &Order) -> Result<Matches>;
    fn allocate(&mut self, order: Order);
}
A trait for order book side implementations.

Implementors provide logic for crossing orders against the book and allocating orders to the book.

Required Methods

fn try_cross(&mut self, order: &Order) -> Result<Matches>

Attempts to cross an order against existing orders on this side of the book.

fn allocate(&mut self, order: Order)

Allocates an order to this side of the book (after no-cross or partial cross).

Implementors