pub enum Error {
InvalidSymbol {
expected: Symbol,
received: Symbol,
},
LimitBuyOrderWorstThanTopOfSells {
limit_price: D128,
sell_price: D128,
},
LimitSellOrderWorstThanTopOfBuys {
limit_price: D128,
buy_price: D128,
},
LimitPriceNotBetterThanTop {
book_side: BookSide,
limit_price: Price,
top_order_price: Price,
},
DecimalParseError(ParseError),
}Expand description
Errors that can occur during order book operations.
Variants
InvalidSymbol
The order symbol does not match the order book symbol.
LimitBuyOrderWorstThanTopOfSells
A limit buy order’s price is not better than (i.e., not higher than) the best ask.
LimitSellOrderWorstThanTopOfBuys
A limit sell order’s price is not better than (i.e., not lower than) the best bid.
LimitPriceNotBetterThanTop
A limit order’s price does not improve upon the top order on the book.
DecimalParseError(ParseError)
Failed to parse a decimal string (price or quantity).